@@ -9,10 +9,10 @@ pub fn error_chain_fmt(
     e: &impl std::error::Error,
     f: &mut std::fmt::Formatter<'_>,
 ) -> std::fmt::Result {
-    writeln!(f, "{}\n", e)?;
+    writeln!(f, "{e}\n")?;
     let mut current = e.source();
     while let Some(cause) = current {
-        writeln!(f, "Caused by:\n\t{}", cause)?;
+        writeln!(f, "Caused by:\n\t{cause}")?;
         current = cause.source();
     }
     Ok(())
