@@ -5,7 +5,7 @@
 // http://opensource.org/licenses/MIT>, at your option. This file may not be
 // copied, modified, or distributed except according to those terms.
 
-use opentelemetry::sdk::metrics::MeterProvider;
+use opentelemetry_sdk::metrics::MeterProvider;
 use prometheus::Registry;
 
 mod database;
