@@ -1,5 +1,5 @@
 use crate::helpers::spawn_app;
-use auditor::client::AuditorClientBuilder;
+use auditor::client::{AuditorClientBuilder, Operator, QueryBuilder};
 use auditor::domain::{Component, Record, RecordAdd, RecordDatabase, RecordTest, RecordUpdate};
 use chrono::{TimeZone, Utc};
 use fake::{Fake, Faker};
@@ -244,7 +244,7 @@ async fn get_returns_a_list_of_records() {
             runtime,
             Utc::now()
         )
-        .fetch_optional(&mut transaction)
+        .fetch_optional(&mut *transaction)
         .await
         .unwrap()
         .unwrap()
@@ -288,7 +288,7 @@ async fn get_returns_a_list_of_records() {
                 &scores[..],
                 id,
             )
-            .execute(&mut transaction)
+            .execute(&mut *transaction)
             .await
             .unwrap();
         }
@@ -316,7 +316,7 @@ async fn get_returns_a_list_of_records() {
                 &names[..],
                 &values[..],
             )
-            .execute(&mut transaction)
+            .execute(&mut *transaction)
             .await
             .unwrap();
         }
@@ -385,7 +385,7 @@ async fn get_started_since_returns_a_list_of_records() {
             runtime,
             Utc::now()
         )
-        .fetch_optional(&mut transaction)
+        .fetch_optional(&mut *transaction)
         .await
         .unwrap()
         .unwrap()
@@ -429,7 +429,7 @@ async fn get_started_since_returns_a_list_of_records() {
                 &scores[..],
                 id,
             )
-            .execute(&mut transaction)
+            .execute(&mut *transaction)
             .await
             .unwrap();
         }
@@ -457,7 +457,7 @@ async fn get_started_since_returns_a_list_of_records() {
                 &names[..],
                 &values[..],
             )
-            .execute(&mut transaction)
+            .execute(&mut *transaction)
             .await
             .unwrap();
         }
@@ -465,8 +465,11 @@ async fn get_started_since_returns_a_list_of_records() {
         transaction.commit().await.unwrap();
     }
 
-    let mut received_records = client
-        .get_started_since(&Utc.with_ymd_and_hms(2022, 3, 15, 0, 0, 0).unwrap())
+    let date = Utc.with_ymd_and_hms(2022, 3, 15, 0, 0, 0).unwrap();
+
+    let mut received_records = QueryBuilder::new()
+        .with_start_time(Operator::default().gte(date.into()))
+        .get(client)
         .await
         .unwrap();
 
@@ -534,7 +537,7 @@ async fn get_stopped_since_returns_a_list_of_records() {
             runtime,
             Utc::now()
         )
-        .fetch_optional(&mut transaction)
+        .fetch_optional(&mut *transaction)
         .await
         .unwrap()
         .unwrap()
@@ -578,7 +581,7 @@ async fn get_stopped_since_returns_a_list_of_records() {
                 &scores[..],
                 id,
             )
-            .execute(&mut transaction)
+            .execute(&mut *transaction)
             .await
             .unwrap();
         }
@@ -606,7 +609,7 @@ async fn get_stopped_since_returns_a_list_of_records() {
                 &names[..],
                 &values[..],
             )
-            .execute(&mut transaction)
+            .execute(&mut *transaction)
             .await
             .unwrap();
         }
@@ -614,8 +617,10 @@ async fn get_stopped_since_returns_a_list_of_records() {
         transaction.commit().await.unwrap();
     }
 
-    let mut received_records = client
-        .get_stopped_since(&Utc.with_ymd_and_hms(2022, 3, 15, 0, 0, 0).unwrap())
+    let date = Utc.with_ymd_and_hms(2022, 3, 15, 0, 0, 0).unwrap();
+    let mut received_records = QueryBuilder::new()
+        .with_stop_time(Operator::default().gte(date.into()))
+        .get(client)
         .await
         .unwrap();
 
