@@ -1,6 +1,8 @@
 mod add;
+mod advanced_queries;
 mod client;
 mod get;
+mod get_one_record;
 mod get_since;
 mod health_check;
 mod helpers;
