@@ -3,7 +3,6 @@
 import asyncio
 from pyauditor import AuditorClientBuilder, Record, Component, Score
 import datetime
-import pytz
 from tzlocal import get_localzone
 
 
@@ -27,16 +26,14 @@ async def main():
     # datetimes sent to auditor MUST BE in UTC.
     start = datetime.datetime(
         2021, 12, 6, 16, 29, 43, 79043, tzinfo=local_tz
-    ).astimezone(pytz.utc)
-    # stop = datetime.datetime(2022, 8, 9, 3, 0, 0, 0, tzinfo=pytz.utc)
+    ).astimezone(datetime.timezone.utc)
+    # stop = datetime.datetime(2022, 8, 9, 3, 0, 0, 0, tzinfo=datetime.timezone.utc)
     score1 = Score("HEPSPEC", 1.0)
     score2 = Score("OTHERSPEC", 4.0)
     component1 = Component("comp-1", 10).with_score(score1)
     component2 = Component("comp-2", 100).with_score(score1).with_score(score2)
     record = (
-        Record(record_id, start)
-        .with_component(component1)
-        .with_component(component2)
+        Record(record_id, start).with_component(component1).with_component(component2)
     )
 
     await client.add(record)
@@ -45,7 +42,7 @@ async def main():
     assert len(records) == 1
     record = records[0]
     assert record.record_id == record_id
-    assert record.start_time.replace(tzinfo=pytz.utc) == start
+    assert record.start_time.replace(tzinfo=datetime.timezone.utc) == start
     assert record.components[0].name == "comp-1"
     assert record.components[0].amount == 10
     assert record.components[0].scores[0].name == "HEPSPEC"
